@@ -53,7 +53,54 @@ def function(fun, wrt=0, ntrax=0, parallel=False):
     return evaluate_function
 
 
-def gradient(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
+def jacobian(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
+    "Evaluate the jacobian of a function."
+
+    def evaluate_jacobian(*args, **kwargs):
+
+        x = arg_to_tensor(args, kwargs, wrt)
+        t = Tensor(x, ntrax=ntrax)
+        δx = Δx = np.eye(t.size)
+        indices = range(t.size)
+
+        args0, kwargs0 = add_tensor(args, kwargs, wrt, None, None, ntrax)
+        shape = fun(*args0, **kwargs0).shape
+        axes = tuple([slice(None)] * len(shape))
+
+        fx = np.zeros((*shape, *t.trax))
+        dfdx = np.zeros((*shape, t.size, *t.trax))
+
+        def kernel(a, wrt, δx, Δx, ntrax, args, kwargs):
+            args, kwargs = add_tensor(args, kwargs, wrt, δx[a], Δx[a], ntrax)
+            func = fun(*args, **kwargs)
+            fx[axes] = f(func)
+            dfdx[(*axes, a)] = δ(func)
+
+        if not parallel:
+            for a in indices:
+                kernel(a, wrt, δx, Δx, ntrax, args, kwargs)
+
+        else:
+            threads = [
+                Thread(target=kernel, args=(a, wrt, δx, Δx, ntrax, args, kwargs))
+                for a in indices
+            ]
+
+            for th in threads:
+                th.start()
+
+            for th in threads:
+                th.join()
+
+        if full_output:
+            return np.array(dfdx).reshape(*shape, *t.shape, *t.trax), fx
+        else:
+            return np.array(dfdx).reshape(*shape, *t.shape, *t.trax)
+
+    return evaluate_jacobian
+
+
+def gradient(fun, wrt=0, ntrax=0, parallel=False, full_output=False, sym=False):
     "Evaluate the gradient of a scalar-valued function."
 
     def evaluate_gradient(*args, **kwargs):
@@ -66,6 +113,10 @@ def gradient(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
         dfdx = np.zeros((t.size, *t.trax))
         δx = Δx = np.eye(t.size)
 
+        if sym:
+            idx_off_diag = {1: None, 3: [1], 6: [1, 2, 4]}[t.size]
+            δx[idx_off_diag] /= 2
+
         def kernel(a, wrt, δx, Δx, ntrax, args, kwargs):
             args, kwargs = add_tensor(args, kwargs, wrt, δx[a], Δx[a], ntrax)
             func = fun(*args, **kwargs)
@@ -96,7 +147,7 @@ def gradient(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
     return evaluate_gradient
 
 
-def hessian(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
+def hessian(fun, wrt=0, ntrax=0, parallel=False, full_output=False, sym=False):
     "Evaluate the hessian of a scalar-valued function."
 
     def evaluate_hessian(*args, **kwargs):
@@ -110,6 +161,10 @@ def hessian(fun, wrt=0, ntrax=0, parallel=False, full_output=False):
         d2fdx2 = np.zeros((t.size, t.size, *t.trax))
         δx = Δx = np.eye(t.size)
 
+        if sym:
+            idx_off_diag = {1: None, 3: [1], 6: [1, 2, 4]}[t.size]
+            δx[idx_off_diag] /= 2
+
         def kernel(a, b, wrt, δx, Δx, ntrax, args, kwargs):
             args, kwargs = add_tensor(args, kwargs, wrt, δx[a], Δx[b], ntrax)
             func = fun(*args, **kwargs)
