@@ -9,6 +9,7 @@ r"""
 """
 
 from . import _linalg as linalg
+from . import _special as special
 from ._math_tensor import (
     sin,
     cos,
@@ -29,5 +30,6 @@ from ._math_tensor import (
     matmul,
     diagonal,
     ravel,
+    reshape,
 )
 from . import _math_array as array
