@@ -63,14 +63,32 @@ def test_math():
     ]:
         assert np.allclose(fun(F), fun(T).x)
 
-    for fun in [tm.linalg.det]:
+    for fun in [tm.linalg.det, tm.linalg.inv]:
         assert np.allclose(fun(F), fun(T).x)
 
+    for fun in [
+        tm.special.dev,
+        tm.special.tresca,
+        tm.special.von_mises,
+        tm.special.sym,
+    ]:
+        fun(T)
+
     assert tm.linalg.eigvalsh(T).shape == (3,)
 
+    assert tm.linalg.expm(T).shape == (3, 3)
+
     assert tm.array.cross(F, F).shape == F.shape
     assert tm.array.eye(F).shape == F.shape
 
+    assert np.allclose(tm.array.eye(F), tm.array.eye(T))
+
+
+def test_einsum():
+
+    F = np.eye(3) + np.arange(1, 10).reshape(3, 3) / 10
+    T = tr.Tensor(F)
+
     tm.einsum("ij...,kl...->ijkl...", F, F)
     tm.einsum("ij...,kl...->ijkl...", F, T)
     tm.einsum("ij...,kl...->ijkl...", T, F)
@@ -88,17 +106,74 @@ def test_math():
     with pytest.raises(NotImplementedError):
         tm.einsum("ij...,kl...,mn...,pq...->ijklmnpq...", T, T, T, T)
 
+
+def test_slice():
+
+    F = np.eye(3) + np.arange(1, 10).reshape(3, 3) / 10
+    T = tr.Tensor(F)
+
     T.ravel()
     T[0] = F[0]
     T[:, 0] = F[:, 0]
     T[:, 0] = T[:, 0]
 
+
+def test_reshape():
+
     x = np.ones((3, 3, 100))
     t = tr.Tensor(x, x, x, x, ntrax=1)
     u = tr.Tensor(x, ntrax=1)
 
     u[0] = t[0]
 
+    t.reshape(9)
+    t.reshape(3, 3)
+
+    tm.reshape(t, (9,))
+    tm.reshape(t, (3, 3))
+
+    tm.reshape(x, (3, 3, 100))
+
+
+def test_eigh():
+
+    F = np.diag([1.2, 1.2, 2.0])
+    T = tr.Tensor(F)
+
+    assert tm.linalg.eigh(T)[0].shape == (3,)
+    assert tm.linalg.eigh(T)[1].shape == (3, 3, 3)
+
+    F = np.tile(F.reshape(3, 3, 1), 5)
+    T = tr.Tensor(F, ntrax=1)
+
+    assert tm.linalg.eigh(T)[0].shape == (3,)
+    assert tm.linalg.eigh(T)[1].shape == (3, 3, 3)
+
+
+def test_triu():
+
+    F = np.tile((np.eye(3) + np.arange(1, 10).reshape(3, 3) / 10).reshape(3, 3, 1), 10)
+    V = tr.Tensor(F, F, F, ntrax=1)
+    T = V.T() @ V
+
+    t = tm.special.triu_1d(T)
+    assert t.shape == (6,)
+    assert t.size == 6
+
+    U = tm.special.from_triu_1d(t)
+
+    assert np.allclose(tr.f(T), tr.f(U))
+    assert np.allclose(tr.δ(T), tr.δ(U))
+
+    V = tm.special.from_triu_2d(np.ones((6, 6, 10)))
+
+    assert V.shape == (3, 3, 3, 3, 10)
+
 
 if __name__ == "__main__":
     test_math()
+    test_einsum()
+    test_slice()
+    test_reshape()
+    test_eigh()
+    test_triu()
